@@ -23,7 +23,7 @@ from numpy import (
     repeat,
 )
 from numpy.random import randint
-from itertools import islice, count, repeat
+from itertools import islice, count
 from datetime import datetime as dt
 
 second_ms = 1000.0
@@ -74,19 +74,18 @@ class BinarySound(object):
 
         # TODO: Repair: TypeError: unsupported operand type(s) for *: 'int' and 'map'
 
-        # >>> from hum.gen.diagnosis_sounds import BinarySound
-        # >>> from numpy import *
-        # >>> from numpy.random import randint
-        # >>>
-        # >>> nbits=50
-        # >>> bs = BinarySound(
-        # ...     nbits=nbits, redundancy=142, repetition=3, header_size_words=1)
-        # >>> utc = randint(0, 2, nbits)
-        # >>> wf = bs.mk_phrase(utc)
-        # >>> print(bs)
-        # {'repetition': 3, 'word_size_frm': 150, 'redundancy': 142, 'phrase_data_frm': 21300}
-        # >>> all(utc == bs.decode(wf))
-        # True
+        >>> from numpy import *
+        >>> from numpy.random import randint
+        >>>
+        >>> nbits=50
+        >>> bs = BinarySound(
+        ...     nbits=nbits, redundancy=142, repetition=3, header_size_words=1)
+        >>> utc = randint(0, 2, nbits)
+        >>> wf = bs.mk_phrase(utc)
+        >>> print(bs)
+        {'repetition': 3, 'word_size_frm': 150, 'redundancy': 142, 'phrase_data_frm': 21300}
+        >>> all(utc == bs.decode(wf))
+        True
         """
         self.nbits = nbits
 
@@ -120,9 +119,10 @@ class BinarySound(object):
             }, 'header_pattern must be an array of 0s and 1s'
         self.header_pattern = header_pattern
         self.header_word = tile(
-            map(list, repeat(self.header_pattern, self.repetition)),
+            repeat(self.header_pattern, self.repetition),
             self.header_size_words,
         )
+
         self.phrase_data_frm = self.redundancy * self.word_size_frm
 
     @classmethod
@@ -148,7 +148,6 @@ class BinarySound(object):
             * an explicit array of nbits 0s and 1s to use for the header
             * a string indicating a method to generate it (for now, choices are "halfhalf" or "alternating")
         :return: a BinarySound object
-        >>> from oto.sound.diagnosis_sounds import BinarySound
         >>> from numpy import *
         >>> from numpy.random import randint
         >>>
@@ -186,15 +185,9 @@ class BinarySound(object):
         return self
 
     def mk_phrase(self, bit_array):
-        wf = hstack(
-            (
-                self.header_word,
-                tile(
-                    map(list, repeat(bit_array, self.repetition)),
-                    self.redundancy,
-                ),
-            )
-        )
+        repeated_bit_array = repeat(bit_array, self.repetition)
+        tiled = tile(repeated_bit_array, self.redundancy)
+        wf = hstack((self.header_word, tiled))
         return (2 * wf) - 1
 
     def mk_utc_phrases(self, sound_duration_s=12):
